==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/UploadStringCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { UploadStringCompletedEventArgsDescription } from "./UploadStringCompletedEventArgsDescription";
/**
 * @hidden
 */
var UploadStringCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(UploadStringCompletedEventArgsDescriptionMetadata, _super);
    function UploadStringCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UploadStringCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (UploadStringCompletedEventArgsDescriptionMetadata.a == null) {
            UploadStringCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            UploadStringCompletedEventArgsDescriptionMetadata.c(UploadStringCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.j(UploadStringCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(UploadStringCompletedEventArgsDescriptionMetadata.a);
    };
    UploadStringCompletedEventArgsDescriptionMetadata.c = function (a) {
        AsyncCompletedEventArgsDescriptionMetadata.c(a);
    };
    UploadStringCompletedEventArgsDescriptionMetadata.d = function (a) {
        UploadStringCompletedEventArgsDescriptionMetadata.b(a);
        a.aa("UploadStringCompletedEventArgs", function () { return new UploadStringCompletedEventArgsDescription(); });
        a.z("UploadStringCompletedEventArgs", UploadStringCompletedEventArgsDescriptionMetadata.a);
    };
    UploadStringCompletedEventArgsDescriptionMetadata.$t = markType(UploadStringCompletedEventArgsDescriptionMetadata, 'UploadStringCompletedEventArgsDescriptionMetadata');
    UploadStringCompletedEventArgsDescriptionMetadata.a = null;
    return UploadStringCompletedEventArgsDescriptionMetadata;
}(Base));
export { UploadStringCompletedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/UploadStringCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { UploadStringCompletedEventArgsDescription } from "./UploadStringCompletedEventArgsDescription";
/**
 * @hidden
 */
var UploadStringCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(UploadStringCompletedEventArgsDescriptionMetadata, _super);
    function UploadStringCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UploadStringCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (UploadStringCompletedEventArgsDescriptionMetadata.a == null) {
            UploadStringCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            UploadStringCompletedEventArgsDescriptionMetadata.c(UploadStringCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.k(UploadStringCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(UploadStringCompletedEventArgsDescriptionMetadata.a);
    };
    UploadStringCompletedEventArgsDescriptionMetadata.c = function (a) {
        AsyncCompletedEventArgsDescriptionMetadata.c(a);
    };
    UploadStringCompletedEventArgsDescriptionMetadata.d = function (a) {
        UploadStringCompletedEventArgsDescriptionMetadata.b(a);
        a.ac("UploadStringCompletedEventArgs", function () { return new UploadStringCompletedEventArgsDescription(); });
        a.ab("UploadStringCompletedEventArgs", UploadStringCompletedEventArgsDescriptionMetadata.a);
    };
    UploadStringCompletedEventArgsDescriptionMetadata.$t = markType(UploadStringCompletedEventArgsDescriptionMetadata, 'UploadStringCompletedEventArgsDescriptionMetadata');
    UploadStringCompletedEventArgsDescriptionMetadata.a = null;
    return UploadStringCompletedEventArgsDescriptionMetadata;
}(Base));
export { UploadStringCompletedEventArgsDescriptionMetadata };
